@@ -164,17 +164,15 @@ impl CommandChild for Child {
 
     async fn wait(self) -> io::Result<ExitStatus> {
         let Child { mut inner, token } = self;
-        inner.wait().await.map(|ret| {
+        inner.wait().await.inspect(|_ret| {
             drop(token);
-            ret
         })
     }
 
     async fn wait_with_output(self) -> io::Result<Output> {
         let Child { inner, token } = self;
-        inner.wait_with_output().await.map(|ret| {
+        inner.wait_with_output().await.inspect(|_ret| {
             drop(token);
-            ret
         })
     }
 }
@@ -512,7 +510,10 @@ impl CommandCreator for MockCommandCreator {
     }
 
     fn new_command<S: AsRef<OsStr>>(&mut self, _program: S) -> MockCommand {
-        assert!(!self.children.is_empty(), "Too many calls to MockCommandCreator::new_command, or not enough to MockCommandCreator::new_command_spawns!");
+        assert!(
+            !self.children.is_empty(),
+            "Too many calls to MockCommandCreator::new_command, or not enough to MockCommandCreator::new_command_spawns!"
+        );
         //TODO: assert value of program
         MockCommand {
             child: Some(self.children.remove(0)),
@@ -646,10 +647,7 @@ mod test {
     fn test_mock_wait_error() {
         let client = Client::new_num(1);
         let mut creator = MockCommandCreator::new(&client);
-        creator.next_command_spawns(Ok(MockChild::with_error(io::Error::new(
-            io::ErrorKind::Other,
-            "error",
-        ))));
+        creator.next_command_spawns(Ok(MockChild::with_error(io::Error::other("error"))));
         let e = spawn_wait_command(&mut creator, "foo").err().unwrap();
         assert_eq!("error", e.to_string());
     }
